diff --git a/conduits/abbrowserconduit/KPilotCustomFieldEditor.ui b/conduits/abbrowserconduit/KPilotCustomFieldEditor.ui
index 54782b8..63f6897 100644
--- a/conduits/abbrowserconduit/KPilotCustomFieldEditor.ui
+++ b/conduits/abbrowserconduit/KPilotCustomFieldEditor.ui
@@ -2,7 +2,7 @@
KPilotCustomFields
This form lets you edit the custom fields synced from PalmOS handhelds by the addressbook conduit of KPilot.
Reinhold Kainhofer <reinhold@kainhofer.com>
-
+
KPILOT
@@ -24,7 +24,7 @@
0
-
+
mCustomFieldsGroups
@@ -38,7 +38,7 @@
unnamed
-
+
mCustom3Label
@@ -52,7 +52,7 @@
<qt>Edit or enter the value of the third custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
mCustom4Label
@@ -66,7 +66,7 @@
<qt>Edit or enter the value of the fourth custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
X_CUSTOM2
@@ -74,7 +74,7 @@
<qt>Edit or enter the value of the third custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
X_CUSTOM1
@@ -82,7 +82,7 @@
<qt>Edit or enter the value of the second custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
X_CUSTOM3
@@ -90,7 +90,7 @@
<qt>Edit or enter the value of the fourth custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
mCustom2Label
@@ -104,7 +104,7 @@
<qt>Edit or enter the value of the second custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
mCustom1Label
@@ -118,7 +118,7 @@
<qt>Edit or enter the value of the first custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
X_CUSTOM0
@@ -134,7 +134,7 @@
<qt>Edit or enter the value of the first custom field here. Using KPilot, you can synchronize these values with the handheld's Address application custom fields.</qt>
-
+
mCustomFieldsExplanation
@@ -147,7 +147,7 @@
-
+
mMetaSyncGroup
@@ -161,7 +161,7 @@
unnamed
-
+
mRecordIDLabel
@@ -172,7 +172,7 @@
X_RecordID
-
+
mSyncFlagLabel
@@ -217,7 +217,7 @@
-
+
mMetaSyncSettingsWarning
@@ -229,7 +229,7 @@ Do NOT change these values: doing so will almost certainly result in data loss w
WordBreak|AlignVCenter
-
+
X_RecordID
@@ -240,7 +240,7 @@ Do NOT change these values: doing so will almost certainly result in data loss w
2147483647
-
+
X_Flag
diff --git a/conduits/abbrowserconduit/Makefile.am b/conduits/abbrowserconduit/Makefile.am
index 6985522..40c739a 100644
--- a/conduits/abbrowserconduit/Makefile.am
+++ b/conduits/abbrowserconduit/Makefile.am
@@ -11,7 +11,7 @@ conduit_address_la_SOURCES = \
abbrowser-setup.cc \
kabcRecord.cc \
abbrowser-conduit.cc
-conduit_address_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lkdecore -lkio -lkdeui
+conduit_address_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_address_la_LIBADD = ../../lib/libkpilot.la -lkabc -lkabc_file
servicedir = $(kde_servicesdir)
diff --git a/conduits/abbrowserconduit/abbrowser-conduit.cc b/conduits/abbrowserconduit/abbrowser-conduit.cc
index e4f674a..7de5582 100644
--- a/conduits/abbrowserconduit/abbrowser-conduit.cc
+++ b/conduits/abbrowserconduit/abbrowser-conduit.cc
@@ -291,7 +291,7 @@ bool AbbrowserConduit::_loadAddressBook()
emit logError(i18n("You chose to sync with the file \"%1\", which "
"cannot be opened. Please make sure to supply a "
"valid file name in the conduit's configuration dialog. "
- "Aborting the conduit.").arg(AbbrowserSettings::fileName()));
+ "Aborting the conduit.").tqarg(AbbrowserSettings::fileName()));
KIO::NetAccess::removeTempFile(fABookFile);
stopTickle();
return false;
@@ -395,7 +395,7 @@ bool AbbrowserConduit::_saveAddressBook()
if(!KIO::NetAccess::upload(fABookFile, AbbrowserSettings::fileName(), 0L)) {
emit logError(i18n("An error occurred while uploading \"%1\". You can try to upload "
"the temporary local file \"%2\" manually")
- .arg(AbbrowserSettings::fileName()).arg(fABookFile));
+ .tqarg(AbbrowserSettings::fileName()).tqarg(fABookFile));
}
else {
KIO::NetAccess::removeTempFile(fABookFile);
@@ -476,7 +476,7 @@ void AbbrowserConduit::showPilotAddress(const PilotAddress *pilotAddress)
}
DEBUGKPILOT << fname << "\n"
<< pilotAddress->getTextRepresentation(
- fAddressAppInfo,Qt::PlainText) << endl;
+ fAddressAppInfo,TQt::PlainText) << endl;
}
@@ -762,7 +762,7 @@ void AbbrowserConduit::slotDeletedRecord()
recordid_t id = backupRec->id();
TQString uid = addresseeMap[id];
- Addressee e = aBook->tqfindByUid(uid);
+ Addressee e = aBook->findByUid(uid);
DEBUGKPILOT << fname << ": now looking at palm id: ["
<< id << "], kabc uid: [" << uid << "]." << endl;
@@ -779,7 +779,7 @@ void AbbrowserConduit::slotDeletedRecord()
DEBUGKPILOT << fname << ": no Addressee found for this id." << endl;
DEBUGKPILOT << fname << "\n"
<< backupAddr->getTextRepresentation(
- fAddressAppInfo,Qt::PlainText) << endl;
+ fAddressAppInfo,TQt::PlainText) << endl;
if (palmRec) {
DEBUGKPILOT << fname << ": deleting from database on palm." << endl;
@@ -1493,7 +1493,7 @@ TQString AbbrowserConduit::_smartMergeString(const TQString &pc, const TQString
// If this is a first sync, we don't have a backup record, so
if(isFirstSync() || backup.isEmpty()) {
- if (pc.isEmpty() && palm.isEmpty() ) return TQString::null;
+ if (pc.isEmpty() && palm.isEmpty() ) return TQString();
if(pc.isEmpty()) return palm;
if(palm.isEmpty()) return pc;
} else {
@@ -1512,7 +1512,7 @@ TQString AbbrowserConduit::_smartMergeString(const TQString &pc, const TQString
case SyncAction::ePreviousSyncOverrides: return backup; break;
default: break;
}
- return TQString::null;
+ return TQString();
}
@@ -1535,9 +1535,9 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
#define appendGen(desc, abfield, palmfield) \
tab->append(new ResolutionItem(desc, tab->fExistItems, \
- (!pcAddr.isEmpty())?(abfield):(TQString::null), \
- (palmAddr)?(palmAddr->palmfield):(TQString::null), \
- (backupAddr)?(backupAddr->palmfield):(TQString::null) ))
+ (!pcAddr.isEmpty())?(abfield):(TQString()), \
+ (palmAddr)?(palmAddr->palmfield):(TQString()), \
+ (backupAddr)?(backupAddr->palmfield):(TQString()) ))
#define appendAddr(desc, abfield, palmfield) \
appendGen(desc, abfield, getField(palmfield))
#define appendGenPhone(desc, abfield, palmfield) \
@@ -1588,7 +1588,7 @@ bool AbbrowserConduit::_buildResolutionTable(ResolutionTable*tab, const Addresse
tab->fExistItems,
!pcAddr.isEmpty() ?
KABCSync::bestMatchedCategoryName(pcAddr.categories(), *fAddressAppInfo, category) :
- TQString::null,
+ TQString(),
palmAddrCategoryLabel,
backupAddrCategoryLabel));
#undef appendGen
@@ -1843,7 +1843,7 @@ Addressee AbbrowserConduit::_findMatch(const PilotAddress & pilotAddress) const
DEBUGKPILOT << fname << ": PilotRecord has id " << pilotAddress.id() << ", mapped to " << id << endl;
if(!id.isEmpty())
{
- Addressee res(aBook->tqfindByUid(id));
+ Addressee res(aBook->findByUid(id));
if(!res.isEmpty()) return res;
DEBUGKPILOT << fname << ": PilotRecord has id " << pilotAddress.id() << ", but could not be found in the addressbook" << endl;
}
diff --git a/conduits/abbrowserconduit/abbrowser-conduit.h b/conduits/abbrowserconduit/abbrowser-conduit.h
index 22e9446..464378f 100644
--- a/conduits/abbrowserconduit/abbrowser-conduit.h
+++ b/conduits/abbrowserconduit/abbrowser-conduit.h
@@ -54,6 +54,7 @@ typedef TQValueList RecordIDList;
class AbbrowserConduit : public ConduitAction
{
Q_OBJECT
+ TQ_OBJECT
public:
AbbrowserConduit(KPilotLink *o,const char *n = 0L,
const TQStringList &a = TQStringList() );
diff --git a/conduits/abbrowserconduit/abbrowser-setup.cc b/conduits/abbrowserconduit/abbrowser-setup.cc
index f4d80d2..b275d3b 100644
--- a/conduits/abbrowserconduit/abbrowser-setup.cc
+++ b/conduits/abbrowserconduit/abbrowser-setup.cc
@@ -132,7 +132,7 @@ AbbrowserWidgetSetup::~AbbrowserWidgetSetup()
#endif
int fmtindex=fConfigWidget->fCustomDate->currentItem();
AbbrowserSettings::setCustomDateFormat(
- (fmtindex==0)?(TQString::null):fConfigWidget->fCustomDate->currentText() );
+ (fmtindex==0)?(TQString()):fConfigWidget->fCustomDate->currentText() );
AbbrowserSettings::self()->writeConfig();
unmodified();
diff --git a/conduits/abbrowserconduit/kabcRecord.cc b/conduits/abbrowserconduit/kabcRecord.cc
index b713b84..b503031 100644
--- a/conduits/abbrowserconduit/kabcRecord.cc
+++ b/conduits/abbrowserconduit/kabcRecord.cc
@@ -362,7 +362,7 @@ void KABCSync::setFieldFromHHCustom(
bdate = KGlobal::locale()->readDate(value, format, &ok);
}
DEBUGKPILOT << "Birthdate from " << index << "-th custom field: "
- << bdate.toString() << endl;
+ << TQString(bdate.toString()) << endl;
DEBUGKPILOT << "Is Valid: " << bdate.isValid() << endl;
if (bdate.isValid())
{
@@ -437,7 +437,7 @@ TQString KABCSync::getFieldForHHOtherPhone(const KABC::Addressee & abEntry, cons
case eTTYTTDPhone:
return abEntry.phoneNumber(KABC::PhoneNumber::Pcs).number();
default:
- return TQString::null;
+ return TQString();
}
}
diff --git a/conduits/abbrowserconduit/kaddressbookConduit.ui b/conduits/abbrowserconduit/kaddressbookConduit.ui
index 169311f..81e5202 100644
--- a/conduits/abbrowserconduit/kaddressbookConduit.ui
+++ b/conduits/abbrowserconduit/kaddressbookConduit.ui
@@ -1,7 +1,7 @@
AbbrowserWidget
Adriaan de Groot and David Bishop
-
+
Form2
@@ -23,14 +23,14 @@
6
-
+
tabWidget
true
-
+
tab
@@ -58,7 +58,7 @@
-
+
fSyncDestination
@@ -69,7 +69,7 @@
unnamed
-
+
fSyncStdAbook
@@ -80,7 +80,7 @@
<qt>Select this option to synchronize with KDE's standard addressbook (i.e. the addressbook that you edit in KAddressBook, and which you use in KMail)</qt>
-
+
fSyncFile
@@ -115,7 +115,7 @@
-
+
fArchive
@@ -128,7 +128,7 @@
-
+
tab
@@ -139,7 +139,7 @@
unnamed
-
+
groupBox4
@@ -150,7 +150,7 @@
unnamed
-
+
textLabel1_2_2
@@ -172,7 +172,7 @@
<qt>Select in this list how conflicting entries (entries which were edited both on your handheld and on the PC) are resolved. Possibly values are "Use KPilot's Global Setting" to use the settings defined in KPilot HotSync configuration, "Ask User" to let you decide case by case, "Do Nothing" to allow the entries to be different, "PC overrides", "Handheld overrides", "Use values from last sync" and "Use both entries" to create a new entry on both the PC and handheld.</qt>
-
+
-
Use KPilot's Global Setting
@@ -218,7 +218,7 @@
<qt>Select in this list how conflicting entries (entries which were edited both on your handheld and on the PC) are resolved. Possibly values are "Use KPilot's Global Setting" to use the settings defined in KPilot HotSync configuration, "Ask User" to let you decide case by case, "Do Nothing" to allow the entries to be different, "PC overrides", "Handheld overrides", "Use values from last sync" and "Use both entries" to create a new entry on both the PC and handheld.</qt>
-
+
textLabel1_7
@@ -250,7 +250,7 @@
-
+
tab
@@ -267,7 +267,7 @@
6
-
+
TextLabel2
@@ -278,7 +278,7 @@
<qt>Select which KAddressBook field should be used to store the Pilot's "Other" phone here.</qt>
-
+
-
Other Phone
@@ -334,7 +334,7 @@
<qt>Select which KAddressBook field should be used to store the Pilot's "Other" phone here.</qt>
-
+
TextLabel4
@@ -345,7 +345,7 @@
<qt>Select which KAddressBook field should be used to store the Pilot's Street Address here.</qt>
-
+
-
Preferred, then Home Address
@@ -363,7 +363,7 @@
<qt>Select which KAddressBook field should be used to store the Pilot's Street Address here.</qt>
-
+
TextLabel5
@@ -374,7 +374,7 @@
<qt>Select which KAddressBook field should be used to store the Fax number from the Pilot here.</qt>
-
+
-
Home Fax
@@ -411,7 +411,7 @@
-
+
tab
@@ -422,7 +422,7 @@
unnamed
-
+
textLabel1
@@ -441,7 +441,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the first custom field on your handheld.</qt>
-
+
textLabel1_2
@@ -452,7 +452,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the second custom field on your handheld.</qt>
-
+
textLabel1_3
@@ -463,7 +463,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the third custom field on your handheld.</qt>
-
+
textLabel1_4
@@ -474,7 +474,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the fourth custom field on your handheld.</qt>
-
+
-
Store as Custom Field
@@ -510,7 +510,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the first custom field on your handheld.</qt>
-
+
-
Store as Custom Field
@@ -546,7 +546,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the second custom field on your handheld.</qt>
-
+
-
Store as Custom Field
@@ -582,7 +582,7 @@
<qt>Select the field from this list that represents best the meaning given by your use of the third custom field on your handheld.</qt>
-
+
-
Store as Custom Field
@@ -632,7 +632,7 @@
Horizontal
-
+
textLabel1_5
@@ -646,7 +646,7 @@
<qt>Select the birthdate format here, if you selected "birthdate" for any of the custom fields above. Possible placeholders are:<br> %d for the day, %m for the month, %y for the two-digit year, %Y for the four-digit year. For example, %d.%m.%Y would generate a date like 27.3.1952, while %m/%d/%y would write the same date as 03/27/52. </qt>
-
+
-
Locale Settings
diff --git a/conduits/abbrowserconduit/resolutionDialog.h b/conduits/abbrowserconduit/resolutionDialog.h
index 2c7a8b0..68a1d58 100644
--- a/conduits/abbrowserconduit/resolutionDialog.h
+++ b/conduits/abbrowserconduit/resolutionDialog.h
@@ -40,9 +40,10 @@ class ResolutionTable;
class ResolutionDlg : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- ResolutionDlg( TQWidget* parent=0,
+ ResolutionDlg( TQWidget* tqparent=0,
KPilotLink*fH=0L,
const TQString &caption=TQString(),
const TQString &helpText=TQString(),
diff --git a/conduits/abbrowserconduit/resolutionDialog_base.ui b/conduits/abbrowserconduit/resolutionDialog_base.ui
index c561599..5f5442f 100644
--- a/conduits/abbrowserconduit/resolutionDialog_base.ui
+++ b/conduits/abbrowserconduit/resolutionDialog_base.ui
@@ -1,6 +1,6 @@
ResolutionDialogBase
-
+
widget2
@@ -19,7 +19,7 @@
unnamed
-
+
fIntroText
@@ -30,7 +30,7 @@
WordBreak|AlignVCenter
-
+
Field
@@ -55,7 +55,7 @@
<qt>Use this list to resolve, field by field, the conflicts created when a record was edited both on the handheld and on the PC. For each record, the different values from the last sync, the handheld and PC are displayed for each field, allowing you to choose the desired value.</qt>
-
+
textLabel1
@@ -66,7 +66,7 @@
WordBreak|AlignVCenter
-
+
frame3
@@ -77,7 +77,7 @@
unnamed
-
+
fKeepBoth
@@ -88,7 +88,7 @@
<qt>Click this button to use both values, resulting in the duplication of the record.</qt>
-
+
fPCValues
@@ -99,7 +99,7 @@
<qt>Click this button to use the PC values for synchronizing all conflicting fields in this record.</qt>
-
+
fBackupValues
@@ -110,7 +110,7 @@
<qt>Click this button to use the last sync values (old values) for synchronizing all conflicting fields in this record.</qt>
-
+
fPalmValues
diff --git a/conduits/docconduit/DOC-converter.cc b/conduits/docconduit/DOC-converter.cc
index cb097d8..06f45b7 100644
--- a/conduits/docconduit/DOC-converter.cc
+++ b/conduits/docconduit/DOC-converter.cc
@@ -79,7 +79,7 @@ int docMatchBookmark::findMatches(TQString doctext, bmkList &fBookmarks) {
#endif
while (pos >= 0 && foundisOpen()) {
- emit logError(i18n("Unable to open palm doc database %1").arg(docdb->dbPathName()) );
+ emit logError(i18n("Unable to open palm doc database %1").tqarg(docdb->dbPathName()) );
return false;
}
@@ -520,7 +520,7 @@ bool DOCConverter::convertPDBtoTXT()
PilotRecord*headerRec = docdb->readRecordByIndex(0);
if (!headerRec)
{
- emit logError(i18n("Unable to read database header for database %1.").arg(docdb->dbPathName()));
+ emit logError(i18n("Unable to read database header for database %1.").tqarg(docdb->dbPathName()));
KPILOT_DELETE(docdb);
return false;
}
@@ -540,7 +540,7 @@ bool DOCConverter::convertPDBtoTXT()
TQFile docfile(txtfilename);
if (!docfile.open(IO_WriteOnly))
{
- emit logError(i18n("Unable to open output file %1.").arg(txtfilename));
+ emit logError(i18n("Unable to open output file %1.").tqarg(txtfilename));
KPILOT_DELETE(docdb);
return false;
}
@@ -555,7 +555,7 @@ bool DOCConverter::convertPDBtoTXT()
DEBUGKPILOT<<"Record "<dbPathName()));
+ emit logMessage(i18n("Could not read text record #%1 from Database %2").tqarg(i).tqarg(docdb->dbPathName()));
}
}
@@ -574,7 +574,7 @@ bool DOCConverter::convertPDBtoTXT()
bmks.append(bmk);
KPILOT_DELETE(rec);
} else {
- emit logMessage(i18n("Could not read bookmark record #%1 from Database %2").arg(i).arg(docdb->dbPathName()));
+ emit logMessage(i18n("Could not read bookmark record #%1 from Database %2").tqarg(i).tqarg(docdb->dbPathName()));
}
}
// TODO: Sort the list of bookmarks according to their position
@@ -592,7 +592,7 @@ bool DOCConverter::convertPDBtoTXT()
if (!bmkfile.open(IO_WriteOnly))
{
emit logError(i18n("Unable to open file %1 for the bookmarks of %2.")
- .arg(bmkfilename).arg(docdb ->dbPathName()));
+ .tqarg(bmkfilename).tqarg(docdb ->dbPathName()));
}
else
{
diff --git a/conduits/docconduit/DOC-converter.h b/conduits/docconduit/DOC-converter.h
index 802d60f..27198cb 100644
--- a/conduits/docconduit/DOC-converter.h
+++ b/conduits/docconduit/DOC-converter.h
@@ -105,6 +105,7 @@ class docRegExpBookmark:public docMatchBookmark {
class DOCConverter:public TQObject {
Q_OBJECT
+ TQ_OBJECT
private:
PilotDatabase * docdb;
TQString txtfilename;
@@ -121,7 +122,7 @@ public:
} eSortBookmarks;
public:
- DOCConverter(TQObject *parent=0L, const char *name=0L);
+ DOCConverter(TQObject *tqparent=0L, const char *name=0L);
virtual ~ DOCConverter();
TQString readText();
diff --git a/conduits/docconduit/Makefile.am b/conduits/docconduit/Makefile.am
index ade1c66..03b83ad 100644
--- a/conduits/docconduit/Makefile.am
+++ b/conduits/docconduit/Makefile.am
@@ -19,7 +19,7 @@ bin_PROGRAMS = kpalmdoc
libpalmdoc_shared_la_SOURCES = makedoc9.cc pilotDOCHead.cc pilotDOCEntry.cc pilotDOCBookmark.cc DOC-converter.cc
conduit_doc_la_SOURCES = docconduitSettings.kcfgc doc-factory.cc doc-setup.cc doc-conduit.cc doc-setupdialog.ui doc-conflictdialog.cc
-conduit_doc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_doc_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_doc_la_LIBADD = ../../lib/libkpilot.la libpalmdoc_shared.la \
$(LIB_KDEUI) $(LIB_KFILE)
diff --git a/conduits/docconduit/doc-conflictdialog.h b/conduits/docconduit/doc-conflictdialog.h
index f0c8b21..83cb8d4 100644
--- a/conduits/docconduit/doc-conflictdialog.h
+++ b/conduits/docconduit/doc-conflictdialog.h
@@ -54,9 +54,10 @@ typedef struct conflictEntry {
class ResolutionDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- ResolutionDialog( TQWidget* parent=0, const TQString& caption=i18n("Resolution Dialog"), syncInfoList*sinfo=0L, KPilotLink*lnk=0L);
+ ResolutionDialog( TQWidget* tqparent=0, const TQString& caption=i18n("Resolution Dialog"), syncInfoList*sinfo=0L, KPilotLink*lnk=0L);
~ResolutionDialog();
bool hasConflicts;
diff --git a/conduits/docconduit/doc-factory.cc b/conduits/docconduit/doc-factory.cc
index cfab20f4d..47e1d40 100644
--- a/conduits/docconduit/doc-factory.cc
+++ b/conduits/docconduit/doc-factory.cc
@@ -94,7 +94,7 @@ DOCConduitFactory::~DOCConduitFactory()
}
else
{
- WARNINGKPILOT << "Couldn't cast parent to widget." << endl;
+ WARNINGKPILOT << "Couldn't cast tqparent to widget." << endl;
return 0L;
}
}
@@ -107,7 +107,7 @@ DOCConduitFactory::~DOCConduitFactory()
}
else
{
- WARNINGKPILOT << "Couldn't cast parent to KPilotLink" <
DOCWidget
Reinhold Kainhofer
-
+
Form2
@@ -31,11 +31,11 @@
6
-
+
tabWidget
-
+
tab
@@ -46,7 +46,7 @@
unnamed
-
+
TextLabel1
@@ -60,7 +60,7 @@
<qt>Enter here, or select clicking the file picker button, the name and location of the folder used to find and synchronize text files. All files with extension .txt located in this folder will be synced to Palm DOC databases in your handheld.</qt>
-
+
fkeepPDBLocally
@@ -82,7 +82,7 @@
<qt>Enter here, or select clicking the file picker button, the name and location of the folder used to find and synchronize text files. All files with extension .txt located in this folder will be synced to Palm DOC databases in your handheld.</qt>
-
+
fSyncDirection
@@ -99,7 +99,7 @@
6
-
+
RadioButton3
@@ -113,7 +113,7 @@
<qt>Select this option to synchronize texts changed in your PC to Palm DOC databases in your handheld. Palm DOC databases modified in the handheld will not be converted to text files, but texts changed in the PC will be converted to the Palm DOC databases.</qt>
-
+
RadioButton2
@@ -124,7 +124,7 @@
<qt>Select this option to synchronize the changes made to Palm DOC databases in your handheld to the PC text files. Palm DOC databases modified in the handheld will be converted to text files, but texts changed in the PC will not be converted to the Palm DOC databases.</qt>
-
+
RadioButton1
@@ -170,7 +170,7 @@
-
+
tab
@@ -181,7 +181,7 @@
unnamed
-
+
fCompress
@@ -198,7 +198,7 @@
<qt>The Palm DOC format supports compressing the text to save memory. Check this box to enable text compression, so the resulting Palm DOC database will consume about 50% less memory than in uncompressed state. Almost all DOC readers on the Palm support compressed texts.</qt>
-
+
fConvertBookmarks
@@ -229,7 +229,7 @@
-
+
fBookmarksInline
@@ -243,7 +243,7 @@
Check this box to create bookmarks from inline tags in the text. The inline tag consist of tags in the form <* bookmarktext *>. The bookmark location is set using the location of the inline tag in the text, and the name is the text between the <* and the *>. The inline tag (<*...*>) will be removed from the text.
-
+
textLabel1
@@ -254,7 +254,7 @@
fEncoding
-
+
fBookmarksEndtags
@@ -265,7 +265,7 @@
Check this box to convert tags of the form <bookmarkname> at the end of the text to bookmarks. The text inside the tag ("bookmarkname") will be searched in the text, and whenever found, a bookmark will be set there. The endtags <...> will then be removed from the end of the text.
-
+
fBookmarksBmk
@@ -276,14 +276,14 @@
<qt>Check this box to use regular expressions in a file to search the text for bookmarks. The file should have the same name as the text file, but should end in .bmk instead of .txt (for instance, the regular expression file for textname.txt should be textname.bmk). See the documentation for a description of the format of the bmk file.</qt>
-
+
fEncoding
-
+
tab
@@ -311,7 +311,7 @@
-
+
fNoConversionOfBmksOnly
@@ -322,7 +322,7 @@
<qt>Check this box to avoid syncing the text on the handheld to the PC if you only changed the bookmarks on the handheld (but not the text).</qt>
-
+
fPCBookmarks
@@ -333,7 +333,7 @@
unnamed
-
+
radioButton8
@@ -347,7 +347,7 @@
<qt>Check this box to avoid converting Palm DOC bookmarks to inline tags or to a bookmark file.</qt>
-
+
radioButton11
@@ -364,7 +364,7 @@
<qt>Check this box to convert the Palm DOC database bookmarks to a separate file, in the bmk format (see more about this format in the documentation). The resulting bookmark file shares the same filename as the resulting .txt file, but ends in .bmk instead. This approach creates a clean text file and a bookmark file.</qt>
-
+
radioButton9
@@ -382,7 +382,7 @@
-
+
tab
@@ -393,7 +393,7 @@
unnamed
-
+
fConflictResolution
@@ -410,7 +410,7 @@
unnamed
-
+
radioButton12
@@ -424,7 +424,7 @@
<qt>The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to prevent KPilot from overwriting your modifications.</qt>
-
+
RadioButton5
@@ -438,7 +438,7 @@
<qt>The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to make the PDA version overwrite the PC version in case of conflict.</qt>
-
+
RadioButton4
@@ -452,7 +452,7 @@
<qt>The Palm DOC conduit does not feature merging the modifications when a text is changed both in the handheld and in the computer. Therefore, when conflicts appear, the choice is between working with the files out of sync, or discarding the changes in one of them. Select this option to make the PC version overwrite the PDA version in case of conflict.</qt>
-
+
RadioButton7
@@ -471,7 +471,7 @@
-
+
fAlwaysUseResolution
diff --git a/conduits/docconduit/kpalmdoc_dlg.cc b/conduits/docconduit/kpalmdoc_dlg.cc
index f73e392..0958c17 100644
--- a/conduits/docconduit/kpalmdoc_dlg.cc
+++ b/conduits/docconduit/kpalmdoc_dlg.cc
@@ -54,8 +54,8 @@
#include "kpalmdocSettings.h"
-ConverterDlg::ConverterDlg( TQWidget *parent, const TQString& caption)
- : KDialogBase( parent, "converterdialog", false, caption, KDialogBase::Close|KDialogBase::Help|KDialogBase::User1,
+ConverterDlg::ConverterDlg( TQWidget *tqparent, const TQString& caption)
+ : KDialogBase( tqparent, "converterdialog", false, caption, KDialogBase::Close|KDialogBase::Help|KDialogBase::User1,
KDialogBase::Close, true, i18n("&About"))
{
TQWidget *page = makeHBoxMainWidget();
@@ -78,7 +78,7 @@ ConverterDlg::ConverterDlg( TQWidget *parent, const TQString& caption)
ConverterDlg::~ConverterDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void ConverterDlg::writeSettings()
{
@@ -175,8 +175,8 @@ void ConverterDlg::slotToText()
int res=KMessageBox::questionYesNo(this,
i18n("You selected to sync folders, "
"but gave a filename instead (%1)."
- "
Use folder %2 instead?").arg(pdburl)
- .arg(pdbinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "
Use folder %2 instead?").tqarg(pdburl)
+ .tqarg(pdbinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes)
{
pdburl=pdbinfo.dirPath(true);
@@ -191,7 +191,7 @@ void ConverterDlg::slotToText()
KMessageBox::sorry(this,
i18n("The folder %1 for "
"the handheld database files is not a valid "
- "folder.").arg(pdburl));
+ "folder.").tqarg(pdburl));
return;
}
@@ -200,7 +200,7 @@ void ConverterDlg::slotToText()
KMessageBox::sorry(this,
i18n("The folder %1 for "
"the handheld database files is not a "
- "valid directory.").arg(pdburl));
+ "valid directory.").tqarg(pdburl));
return;
}
@@ -211,8 +211,8 @@ void ConverterDlg::slotToText()
int res=KMessageBox::questionYesNo(this,
i18n("You selected to sync folders, "
"but gave a filename instead (%1)."
- "
Use folder %2 instead?").arg(txturl)
- .arg(txtinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "
Use folder %2 instead?").tqarg(txturl)
+ .tqarg(txtinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes) {
txturl=txtinfo.dirPath(true);
txtinfo.setFile(txturl);
@@ -227,7 +227,7 @@ void ConverterDlg::slotToText()
if (!txtinfo.isDir()) {
KMessageBox::sorry(this,
i18n("The folder %1 for "
- "the text files could not be created.").arg(txturl));
+ "the text files could not be created.").tqarg(txturl));
return;
}
@@ -265,7 +265,7 @@ void ConverterDlg::slotToText()
if (!pdbinfo.isFile() || !pdbinfo.exists())
{
KMessageBox::sorry(this, i18n("The file %1 does not "
- "exist.").arg(pdburl));
+ "exist.").tqarg(pdburl));
return;
}
@@ -274,13 +274,13 @@ void ConverterDlg::slotToText()
if (!txtinfo.isFile())
{
KMessageBox::sorry(this, i18n("The filename %1 for the "
- "text is not a valid filename.").arg(txturl));
+ "text is not a valid filename.").tqarg(txturl));
return;
}*/
if (convertPDBtoTXT(pdbinfo.dirPath(true), pdbinfo.fileName(),
txtinfo.dirPath(true), txtinfo.fileName(), &conv) )
{
- KMessageBox::information(this, i18n("Conversion of file %1 successful.").arg(pdburl));
+ KMessageBox::information(this, i18n("Conversion of file %1 successful.").tqarg(pdburl));
}
}
@@ -324,8 +324,8 @@ void ConverterDlg::slotToPDB()
int res=KMessageBox::questionYesNo(this,
i18n("You selected to sync folders, "
"but gave a filename instead (%1)."
- "
Use folder %2 instead?").arg(txturl)
- .arg(txtinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ "
Use folder %2 instead?").tqarg(txturl)
+ .tqarg(txtinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes)
{
txturl=txtinfo.dirPath(true);
@@ -338,7 +338,7 @@ void ConverterDlg::slotToPDB()
{
KMessageBox::sorry(this,
i18n("The folder %1 for "
- "the text files is not a valid folder.").arg(txturl));
+ "the text files is not a valid folder.").tqarg(txturl));
return;
}
@@ -350,8 +350,8 @@ void ConverterDlg::slotToPDB()
i18n("You selected to sync folders, "
"but gave a filename instead (%1)."
"
Use folder %2 instead?")
- .arg(pdburl)
- .arg(pdbinfo.dirPath(true)), TQString::null, i18n("Use Folder"), KStdGuiItem::cancel());
+ .tqarg(pdburl)
+ .tqarg(pdbinfo.dirPath(true)), TQString(), i18n("Use Folder"), KStdGuiItem::cancel());
if (res==KMessageBox::Yes) {
pdburl=pdbinfo.dirPath(true);
pdbinfo.setFile(pdburl);
@@ -365,7 +365,7 @@ void ConverterDlg::slotToPDB()
}
if (!pdbinfo.isDir()) {
KMessageBox::sorry(this, i18n("The folder %1 for "
- "the PalmDOC files could not be created.").arg(pdburl));
+ "the PalmDOC files could not be created.").tqarg(pdburl));
return;
}
@@ -403,14 +403,14 @@ void ConverterDlg::slotToPDB()
if (!txtinfo.isFile() || !txtinfo.exists())
{
KMessageBox::sorry(this, i18n("The file %1 does not "
- "exist.").arg(txturl));
+ "exist.").tqarg(txturl));
return;
}
if (convertTXTtoPDB(txtinfo.dirPath(true), txtinfo.fileName(),
pdbinfo.dirPath(true), pdbinfo.fileName(), &conv) )
{
- KMessageBox::information(this, i18n("Conversion of file %1 successful.").arg(txturl));
+ KMessageBox::information(this, i18n("Conversion of file %1 successful.").tqarg(txturl));
}
}
@@ -454,7 +454,7 @@ bool ConverterDlg::convertTXTtoPDB(TQString txtdir, TQString txtfile,
if (!dbfileinfo.exists() || !askOverwrite ||
(KMessageBox::Yes==KMessageBox::questionYesNo(this,
i18n("The database file %1 already exists. Overwrite it?")
- .arg(dbfileinfo.filePath()), TQString::null, i18n("Overwrite"), KStdGuiItem::cancel() ) ))
+ .tqarg(dbfileinfo.filePath()), TQString(), i18n("Overwrite"), KStdGuiItem::cancel() ) ))
{
PilotLocalDatabase*pdbdb=new PilotLocalDatabase(pdbdir, TQFileInfo(pdbfile).baseName(), false);
if (pdbdb)
@@ -479,7 +479,7 @@ bool ConverterDlg::convertTXTtoPDB(TQString txtdir, TQString txtfile,
}
if ( !res && verbose )
{
- KMessageBox::sorry(this, i18n("Error while converting the text %1.").arg(txtfile));
+ KMessageBox::sorry(this, i18n("Error while converting the text %1.").tqarg(txtfile));
}
}
else
@@ -499,7 +499,7 @@ bool ConverterDlg::convertPDBtoTXT(TQString pdbdir, TQString pdbfile,
if (!txtfileinfo.exists() || !askOverwrite ||
(KMessageBox::Yes==KMessageBox::questionYesNo(this,
i18n("The text file %1 already exists. Overwrite it?")
- .arg(txtfileinfo.filePath()), TQString::null, i18n("Overwrite"), KStdGuiItem::cancel() ) ))
+ .tqarg(txtfileinfo.filePath()), TQString(), i18n("Overwrite"), KStdGuiItem::cancel() ) ))
{
PilotLocalDatabase*pdbdb=new PilotLocalDatabase(pdbdir, TQFileInfo(pdbfile).baseName(), false);
if (pdbdb)
@@ -515,7 +515,7 @@ bool ConverterDlg::convertPDBtoTXT(TQString pdbdir, TQString pdbfile,
}
if ( !res && verbose )
{
- KMessageBox::sorry(this, i18n("Error while converting the text %1.").arg(pdbfile));
+ KMessageBox::sorry(this, i18n("Error while converting the text %1.").tqarg(pdbfile));
}
}
else
diff --git a/conduits/docconduit/kpalmdoc_dlg.h b/conduits/docconduit/kpalmdoc_dlg.h
index 5e9202b..6fe6e57 100644
--- a/conduits/docconduit/kpalmdoc_dlg.h
+++ b/conduits/docconduit/kpalmdoc_dlg.h
@@ -35,9 +35,10 @@ class DOCConverter;
class ConverterDlg : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- ConverterDlg( TQWidget *parent=0, const TQString& caption=0);
+ ConverterDlg( TQWidget *tqparent=0, const TQString& caption=0);
~ConverterDlg();
protected slots:
diff --git a/conduits/docconduit/kpalmdoc_dlgbase.ui b/conduits/docconduit/kpalmdoc_dlgbase.ui
index ee2bd2a..2b5b581 100644
--- a/conduits/docconduit/kpalmdoc_dlgbase.ui
+++ b/conduits/docconduit/kpalmdoc_dlgbase.ui
@@ -1,6 +1,6 @@
ConverterDlgBase
-
+
ConverterDlgBase
@@ -16,11 +16,11 @@
unnamed
-
+
tabWidget
-
+
tab
@@ -31,7 +31,7 @@
unnamed
-
+
fPdbLabel
@@ -50,7 +50,7 @@
fPDBDir
-
+
fTextLabel
@@ -69,7 +69,7 @@
fTXTDir
-
+
fDirectories
@@ -85,7 +85,7 @@
Folder where copies of the handheld databases are kept. You can install them to any PalmOS handheld, and distribute these copies to other people (but beware of copyright infringement).
-
+
fAskOverwrite
@@ -93,7 +93,7 @@
&Ask before overwriting files
-
+
fVerbose
@@ -142,12 +142,12 @@
Enter the name of the folder where the text files reside on the PC. All files with extension .txt will be synced to the handheld.
-
+
fEncoding
-
+
textLabel1
@@ -160,7 +160,7 @@
-
+
tab
@@ -222,7 +222,7 @@
-
+
fBookmarksInline
@@ -236,7 +236,7 @@
When a <* bookmarktext *> appears somewhere in the text, a bookmark will be set at this position, and the text between the <* and the *> will be used as bookmark name. The <*...*> will be removed from the text.
-
+
fBookmarksEndtags
@@ -247,7 +247,7 @@
Tags of the form <bookmarkname> at the end of the text will be used to search the text for the pattern between the < and >. Whenever "bookmarkname" appears in the text, a bookmark will be set there. The endtags <...> will then be removed from the end of the text.
-
+
fCompress
@@ -264,7 +264,7 @@
The Palm doc format supports compressing the text to save memory. If you check this box, the text will consume about 50% less memory than in uncompressed state. Almost all DOC readers on the Palm support compressed texts.
-
+
fConvertBookmarks
@@ -278,7 +278,7 @@
Do you want to convert bookmarks? Most doc readers support bookmarks. You have to provide some information about where the bookmarks should be set and their titles. Check at least one of the bookmark types below.
-
+
fBookmarksBmk
@@ -308,7 +308,7 @@
-
+
tab
@@ -336,7 +336,7 @@
-
+
fPCBookmarks
@@ -347,7 +347,7 @@
unnamed
-
+
radioButton9
@@ -361,7 +361,7 @@
1
-
+
radioButton8
@@ -375,7 +375,7 @@
0
-
+
radioButton10
@@ -386,7 +386,7 @@
Convert as &end tags
-
+
radioButton11
diff --git a/conduits/knotes/Makefile.am b/conduits/knotes/Makefile.am
index b13a2ff..3161798 100644
--- a/conduits/knotes/Makefile.am
+++ b/conduits/knotes/Makefile.am
@@ -15,7 +15,7 @@ conduit_knotes_la_SOURCES = \
knotes-action.cc \
setup_base.ui
-conduit_knotes_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_knotes_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui -lkcal
conduit_knotes_la_LIBADD = ../../lib/libkpilot.la $(LIB_KDEUI)
kde_kcfg_DATA = knotesconduit.kcfg
diff --git a/conduits/knotes/knotes-action.cc b/conduits/knotes/knotes-action.cc
index 26b595e..e29dedc 100644
--- a/conduits/knotes/knotes-action.cc
+++ b/conduits/knotes/knotes-action.cc
@@ -79,7 +79,7 @@ public:
int memo() const { return memoId; } ;
KNoteID_t note() const { return noteId; } ;
inline bool valid() const { return (memoId>0) && (!noteId.isEmpty()) ; } ;
- TQString toString() const { return CSL1("<%1,%2>").arg(noteId).arg(memoId); } ;
+ TQString toString() const { return CSL1("<%1,%2>").tqarg(noteId).tqarg(memoId); } ;
static NoteAndMemo findNote(const TQValueList &,KNoteID_pt note);
static NoteAndMemo findMemo(const TQValueList &,int memo);
@@ -234,7 +234,7 @@ KNotesAction::KNotesAction(KPilotLink *o,
}
fP->fTimer = new TQTimer(this);
- fActionStatus = Init;
+ fActiontqStatus = Init;
// this is not needed. As it is done in the initstate in process();
// resetIndexes();
@@ -269,7 +269,7 @@ bool KNotesAction::openKNotesResource()
}
else
{
- emit logError( i18n("Could not load the resource at: %1").arg(mURL.path()) );
+ emit logError( i18n("Could not load the resource at: %1").tqarg(mURL.path()) );
return false;
}
}
@@ -308,9 +308,9 @@ void KNotesAction::listNotes()
{
FUNCTIONSETUP;
- DEBUGKPILOT << fname << ": Now in state " << fActionStatus << endl;
+ DEBUGKPILOT << fname << ": Now in state " << fActiontqStatus << endl;
- switch(fActionStatus)
+ switch(fActiontqStatus)
{
case Init:
resetIndexes();
@@ -321,16 +321,16 @@ void KNotesAction::listNotes()
case SyncAction::SyncMode::eBackup:
case SyncAction::SyncMode::eRestore:
// Impossible!
- fActionStatus = Done;
+ fActiontqStatus = Done;
break;
case SyncAction::SyncMode::eCopyHHToPC :
listNotes(); // Debugging
- fActionStatus = MemosToKNotes;
+ fActiontqStatus = MemosToKNotes;
break;
case SyncAction::SyncMode::eHotSync:
case SyncAction::SyncMode::eFullSync:
case SyncAction::SyncMode::eCopyPCToHH:
- fActionStatus = ModifiedNotesToPilot;
+ fActiontqStatus = ModifiedNotesToPilot;
break;
}
break;
@@ -338,14 +338,14 @@ void KNotesAction::listNotes()
if (modifyNoteOnPilot())
{
resetIndexes();
- fActionStatus = DeleteNotesOnPilot;
+ fActiontqStatus = DeleteNotesOnPilot;
}
break;
case DeleteNotesOnPilot:
if (deleteNoteOnPilot())
{
resetIndexes();
- fActionStatus = NewNotesToPilot;
+ fActiontqStatus = NewNotesToPilot;
}
break;
case NewNotesToPilot :
@@ -359,14 +359,14 @@ void KNotesAction::listNotes()
case SyncAction::SyncMode::eRestore:
case SyncAction::SyncMode::eCopyHHToPC :
// Impossible!
- fActionStatus = Done;
+ fActiontqStatus = Done;
break;
case SyncAction::SyncMode::eHotSync:
case SyncAction::SyncMode::eFullSync:
- fActionStatus = MemosToKNotes;
+ fActiontqStatus = MemosToKNotes;
break;
case SyncAction::SyncMode::eCopyPCToHH:
- fActionStatus = Cleanup;
+ fActiontqStatus = Cleanup;
break;
}
}
@@ -374,7 +374,7 @@ void KNotesAction::listNotes()
case MemosToKNotes :
if (syncMemoToKNotes())
{
- fActionStatus=Cleanup;
+ fActiontqStatus=Cleanup;
}
break;
case Cleanup :
@@ -791,7 +791,7 @@ void KNotesAction::cleanupMemos()
KNotesConduitSettings::setMemoIds(memos);
KNotesConduitSettings::self()->writeConfig();
- fActionStatus=Done;
+ fActiontqStatus=Done;
fDatabase->cleanup();
fDatabase->resetSyncFlags();
fLocalDatabase->cleanup();
@@ -848,23 +848,23 @@ void KNotesAction::cleanupMemos()
/* virtual */ TQString KNotesAction::statusString() const
{
- switch(fActionStatus)
+ switch(fActiontqStatus)
{
case Init : return CSL1("Init");
case NewNotesToPilot :
return CSL1("NewNotesToPilot key=%1");
- // TODO DCOP_REMOVAL .arg(fP->fIndex.key());
+ // TODO DCOP_REMOVAL .tqarg(fP->fIndex.key());
case ModifiedNotesToPilot :
return CSL1("ModifiedNotesToPilot key=%1");
- //TODO DCOP_REMOVAL .arg(fP->fIndex.key());
+ //TODO DCOP_REMOVAL .tqarg(fP->fIndex.key());
case MemosToKNotes :
return CSL1("MemosToKNotes rec=%1")
- .arg(fP->fRecordIndex);
+ .tqarg(fP->fRecordIndex);
case Cleanup : return CSL1("Cleanup");
case Done :
return CSL1("Done");
default :
- return CSL1("Unknown (%1)").arg(fActionStatus);
+ return CSL1("Unknown (%1)").tqarg(fActiontqStatus);
}
}
diff --git a/conduits/knotes/knotes-action.h b/conduits/knotes/knotes-action.h
index eb490e0..223dfe2 100644
--- a/conduits/knotes/knotes-action.h
+++ b/conduits/knotes/knotes-action.h
@@ -37,6 +37,7 @@ class PilotMemo;
class KNotesAction : public ConduitAction
{
Q_OBJECT
+ TQ_OBJECT
public:
KNotesAction(
KPilotLink *o,
@@ -44,7 +45,7 @@ public:
const TQStringList &a = TQStringList() );
virtual ~KNotesAction();
- enum Status { Init,
+ enum tqStatus { Init,
ModifiedNotesToPilot,
DeleteNotesOnPilot,
NewNotesToPilot,
diff --git a/conduits/knotes/knotes-factory.cc b/conduits/knotes/knotes-factory.cc
index 9601e81..0abc76a 100644
--- a/conduits/knotes/knotes-factory.cc
+++ b/conduits/knotes/knotes-factory.cc
@@ -123,7 +123,7 @@ KNotesConduitFactory::~KNotesConduitFactory()
else
{
WARNINGKPILOT
- << "Couldn't cast parent to KPilotDeviceLink"
+ << "Couldn't cast tqparent to KPilotDeviceLink"
<< endl;
return 0L;
}
diff --git a/conduits/knotes/knotes-factory.h b/conduits/knotes/knotes-factory.h
index 02b0f61..b8c8311 100644
--- a/conduits/knotes/knotes-factory.h
+++ b/conduits/knotes/knotes-factory.h
@@ -37,6 +37,7 @@ class KAboutData;
class KNotesConduitFactory : public KLibFactory
{
Q_OBJECT
+ TQ_OBJECT
public:
KNotesConduitFactory(TQObject * = 0L,const char * = 0L);
@@ -50,9 +51,9 @@ public:
// break its value. We store group and entry keys in here.
protected:
- virtual TQObject* createObject( TQObject* parent = 0,
+ virtual TQObject* createObject( TQObject* tqparent = 0,
const char* name = 0,
- const char* classname = "TQObject",
+ const char* classname = TQOBJECT_OBJECT_NAME_STRING,
const TQStringList &args = TQStringList() );
private:
KInstance *fInstance;
diff --git a/conduits/knotes/knotes-setup.h b/conduits/knotes/knotes-setup.h
index 652f222..96f008c 100644
--- a/conduits/knotes/knotes-setup.h
+++ b/conduits/knotes/knotes-setup.h
@@ -36,7 +36,7 @@ class KNotesWidget;
class KNotesConfigBase : public ConduitConfigBase
{
public:
- KNotesConfigBase(TQWidget *parent, const char *name);
+ KNotesConfigBase(TQWidget *tqparent, const char *name);
virtual void commit();
virtual void load();
diff --git a/conduits/knotes/setup_base.ui b/conduits/knotes/setup_base.ui
index 6e0fe44..b2007b8 100644
--- a/conduits/knotes/setup_base.ui
+++ b/conduits/knotes/setup_base.ui
@@ -1,6 +1,6 @@
KNotesWidget
-
+
KNotesWidget
@@ -22,11 +22,11 @@
6
-
+
tabWidget
-
+
tab
@@ -37,7 +37,7 @@
unnamed
-
+
fDeleteNoteForMemo
@@ -51,7 +51,7 @@
<qt>Check this box if you wish to delete notes from KNotes automatically when the corresponding Pilot memo is deleted. Use this option with care, as the notes you want to keep in the handheld and in the desktop are not necessarily the same.</qt>
-
+
fSuppressConfirm
diff --git a/conduits/malconduit/Makefile.am b/conduits/malconduit/Makefile.am
index df5ed04..081d129 100644
--- a/conduits/malconduit/Makefile.am
+++ b/conduits/malconduit/Makefile.am
@@ -13,6 +13,6 @@ kde_kcfg_DATA = malconduit.kcfg
kde_module_LTLIBRARIES = conduit_mal.la
conduit_mal_la_SOURCES = malconduitSettings.kcfgc mal-setup_dialog.ui mal-factory.cc mal-setup.cc mal-conduit.cc
-conduit_mal_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_mal_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_mal_la_LIBADD = ../../lib/libkpilot.la $(MAL_LIB) $(LIB_KDEUI)
diff --git a/conduits/malconduit/mal-conduit.cc b/conduits/malconduit/mal-conduit.cc
index 2d3344f..10f1352 100644
--- a/conduits/malconduit/mal-conduit.cc
+++ b/conduits/malconduit/mal-conduit.cc
@@ -217,7 +217,7 @@ bool MALConduit::skip()
syncMessage = i18n("No proxy server is set.");
break;
}
- syncMessage = i18n("Using proxy server: %1").arg(proxyServer);
+ syncMessage = i18n("Using proxy server: %1").tqarg(proxyServer);
#ifdef DEBUG
DEBUGKPILOT<<" Using HTTP proxy server \""<proxyCustomPort->setValue(proxyPortNr);
}
fConfigWidget->proxyUserName->setText(MALConduitSettings::proxyUser());
- fConfigWidget->proxyPassword->setText(TQString::null);
+ fConfigWidget->proxyPassword->setText(TQString());
fConfigWidget->proxyPassword->insert(MALConduitSettings::proxyPassword());
#ifdef DEBUG
diff --git a/conduits/malconduit/mal-setup.h b/conduits/malconduit/mal-setup.h
index 6a63374..6114c28 100644
--- a/conduits/malconduit/mal-setup.h
+++ b/conduits/malconduit/mal-setup.h
@@ -40,6 +40,7 @@ class MALWidget;
class MALWidgetSetup : public ConduitConfigBase
{
Q_OBJECT
+ TQ_OBJECT
public:
MALWidgetSetup(TQWidget *,const char *);
virtual ~MALWidgetSetup();
diff --git a/conduits/malconduit/mal-setup_dialog.ui b/conduits/malconduit/mal-setup_dialog.ui
index 645335b..2bc4c5e 100644
--- a/conduits/malconduit/mal-setup_dialog.ui
+++ b/conduits/malconduit/mal-setup_dialog.ui
@@ -1,7 +1,7 @@
MALWidget
Reinhold Kainhofer
-
+
MalWidget
@@ -23,14 +23,14 @@
6
-
+
tabWidget
true
-
+
tab
@@ -41,7 +41,7 @@
unnamed
-
+
syncTime
@@ -61,7 +61,7 @@
6
-
+
RadioButton1
@@ -78,7 +78,7 @@
<qt>Select this option to synchronize with the MAL server on every HotSync. To perform a successful synchronization, you need to have access to the MAL server during the HotSync.</qt>
-
+
RadioButton1_2
@@ -92,7 +92,7 @@
<qt>Select this option to synchronize with the MAL server on every HotSync that is at least one hour after the previous MAL sync. To perform a successful synchronization, you need to have access to the MAL server during the HotSync.</qt>
-
+
RadioButton1_3
@@ -103,7 +103,7 @@
<qt>Select this option to synchronize with the MAL server on every HotSync that is at least one day after the previous MAL sync. To perform a successful synchronization, you need to have access to the MAL server during the HotSync.</qt>
-
+
RadioButton1_4
@@ -114,7 +114,7 @@
<qt>Select this option to synchronize with the MAL server on every HotSync that is at least one week after the previous MAL sync. To perform a successful synchronization, you need to have access to the MAL server during the HotSync.</qt>
-
+
RadioButton1_5
@@ -146,7 +146,7 @@
-
+
tab
@@ -157,7 +157,7 @@
unnamed
-
+
proxyType
@@ -177,7 +177,7 @@
6
-
+
RadioButton8
@@ -191,7 +191,7 @@
<qt>Select this option if you do not want KPilot to use a proxy server. Use this option if you connect to the internet directly.</qt>
-
+
RadioButton8_2
@@ -202,7 +202,7 @@
<qt>Select this option if you want KPilot to use a HTTP proxy.</qt>
-
+
RadioButton8_2_2
@@ -215,7 +215,7 @@
-
+
proxyServerInformation
@@ -252,7 +252,7 @@
-
+
proxyCustomPortCheck
@@ -263,7 +263,7 @@
Check this box to use a non-standard proxy port.
-
+
TextLabel1
@@ -316,7 +316,7 @@
<qt>If your proxy requires authentication, enter your password here.</qt>
-
+
proxyUserName
@@ -324,7 +324,7 @@
<qt>If your proxy requires authentication, enter your username here.</qt>
-
+
TextLabel2_2
@@ -335,7 +335,7 @@
proxyPassword
-
+
TextLabel2
@@ -363,7 +363,7 @@
Horizontal
-
+
proxyExclude
@@ -371,7 +371,7 @@
<qt>Enter a list of MAL servers that do not need the use of a proxy here, separated with commas, e.g: <br><i>localhost,127.0.0.1,.lan</i><qt>
-
+
textLabel1
@@ -406,7 +406,7 @@
-
+
tab
@@ -423,7 +423,7 @@
6
-
+
GroupBox1_2
@@ -443,7 +443,7 @@
6
-
+
TextLabel1_2
@@ -454,7 +454,7 @@
malServerName
-
+
malCustomPortCheck
@@ -501,12 +501,12 @@
malServerName
-
+
malUserName
-
+
TextLabel2_2_2
@@ -517,7 +517,7 @@
malPassword
-
+
textLabel
@@ -566,7 +566,7 @@
-
+
TextLabel1_3
diff --git a/conduits/memofileconduit/Makefile.am b/conduits/memofileconduit/Makefile.am
index 1f51105..020c569 100644
--- a/conduits/memofileconduit/Makefile.am
+++ b/conduits/memofileconduit/Makefile.am
@@ -10,7 +10,7 @@ kde_module_LTLIBRARIES = conduit_memofile.la
conduit_memofile_la_SOURCES = memofileSettings.kcfgc setup_base.ui \
memofile-factory.cc memofile.cc memofiles.cc memofile-conduit.cc
-conduit_memofile_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_memofile_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_memofile_la_LIBADD = ../../lib/libkpilot.la $(LIB_KDEUI) $(LIB_KFILE)
kde_kcfg_DATA = memofileconduit.kcfg
diff --git a/conduits/memofileconduit/memofile-conduit.cc b/conduits/memofileconduit/memofile-conduit.cc
index 954af38..233f6af 100644
--- a/conduits/memofileconduit/memofile-conduit.cc
+++ b/conduits/memofileconduit/memofile-conduit.cc
@@ -31,7 +31,7 @@
// Only include what we really need:
// First UNIX system stuff, then std C++,
-// then Qt, then KDE, then local includes.
+// then TQt, then KDE, then local includes.
//
//
@@ -120,7 +120,7 @@ MemofileConduit::~MemofileConduit()
fCtrPC->setStartCount(_memofiles->count());
setFirstSync( _memofiles->isFirstSync() );
- addSyncLogEntry(i18n(" Syncing with %1.").arg(_memo_directory));
+ addSyncLogEntry(i18n(" Syncing with %1.").tqarg(_memo_directory));
if ( (syncMode() == SyncAction::SyncMode::eCopyHHToPC) || _memofiles->isFirstSync() ) {
addSyncLogEntry(i18n(" Copying Pilot to PC..."));
@@ -368,7 +368,7 @@ void MemofileConduit::getModifiedFromPilot()
{
FUNCTIONSETUP;
- DEBUGKPILOT << fname << ": Now in state " << fActionStatus << endl;
+ DEBUGKPILOT << fname << ": Now in state " << fActiontqStatus << endl;
}
@@ -448,7 +448,7 @@ void MemofileConduit::deleteUnsyncedHHRecords()
Pilot::RecordIDList::iterator it;
for ( it = ids.begin(); it != ids.end(); ++it )
{
- if (!_memofiles->find(*it))
+ if (!_memofiles->tqfind(*it))
{
DEBUGKPILOT << fname
<< "Deleting record with ID "<< *it <<" from handheld "
diff --git a/conduits/memofileconduit/memofile-conduit.h b/conduits/memofileconduit/memofile-conduit.h
index c795066..d2d07d1 100644
--- a/conduits/memofileconduit/memofile-conduit.h
+++ b/conduits/memofileconduit/memofile-conduit.h
@@ -37,6 +37,7 @@ class PilotMemo;
class MemofileConduit : public ConduitAction
{
Q_OBJECT
+ TQ_OBJECT
public:
MemofileConduit(KPilotLink *,
const char *name=0L,
@@ -52,8 +53,8 @@ protected slots:
private:
// configuration settings...
- QString _DEFAULT_MEMODIR;
- QString _memo_directory;
+ TQString _DEFAULT_MEMODIR;
+ TQString _memo_directory;
bool _sync_private;
PilotMemoInfo *fMemoAppInfo;
diff --git a/conduits/memofileconduit/memofile-factory.cc b/conduits/memofileconduit/memofile-factory.cc
index 795edc3..8b2d9df 100644
--- a/conduits/memofileconduit/memofile-factory.cc
+++ b/conduits/memofileconduit/memofile-factory.cc
@@ -46,7 +46,7 @@
class MemofileConduitConfig : public ConduitConfigBase
{
public:
- MemofileConduitConfig(TQWidget *parent=0L, const char *n=0L);
+ MemofileConduitConfig(TQWidget *tqparent=0L, const char *n=0L);
virtual void commit();
virtual void load();
protected:
diff --git a/conduits/memofileconduit/memofile.h b/conduits/memofileconduit/memofile.h
index 4bd5fb7..1308e98 100644
--- a/conduits/memofileconduit/memofile.h
+++ b/conduits/memofileconduit/memofile.h
@@ -32,7 +32,7 @@
// Only include what we really need:
// First UNIX system stuff, then std C++,
-// then Qt, then KDE, then local includes.
+// then TQt, then KDE, then local includes.
//
//
diff --git a/conduits/memofileconduit/memofileconduit.xmi b/conduits/memofileconduit/memofileconduit.xmi
index 33ff89f..9088d35 100644
--- a/conduits/memofileconduit/memofileconduit.xmi
+++ b/conduits/memofileconduit/memofileconduit.xmi
@@ -34,7 +34,7 @@
-
+
@@ -43,7 +43,7 @@
-
+
@@ -54,8 +54,8 @@
-
-
+
+
@@ -65,7 +65,7 @@
-
+
@@ -79,7 +79,7 @@
-
+
@@ -92,39 +92,39 @@
-
-
-
+
+
+
-
+
-
+
-
+
-
-
+
+
-
+
-
-
+
+
-
+
diff --git a/conduits/memofileconduit/memofiles.cc b/conduits/memofileconduit/memofiles.cc
index c51915b..c8ce67b 100644
--- a/conduits/memofileconduit/memofiles.cc
+++ b/conduits/memofileconduit/memofiles.cc
@@ -89,7 +89,7 @@ void Memofiles::load (bool loadAll)
// DEBUGKPILOT << fname
// << ": checking category: [" << categoryName
// << "], file: [" << file << "]." << endl;
- Memofile * memofile = find(categoryName, file);
+ Memofile * memofile = tqfind(categoryName, file);
if (NULL == memofile) {
memofile = new Memofile(category, categoryName, file, _baseDirectory);
memofile->setModified(true);
@@ -316,7 +316,7 @@ bool Memofiles::loadFromMetadata ()
return true;
}
-Memofile * Memofiles::find (recordid_t id)
+Memofile * Memofiles::tqfind (recordid_t id)
{
Memofile * memofile;
@@ -331,7 +331,7 @@ Memofile * Memofiles::find (recordid_t id)
}
-Memofile * Memofiles::find (const TQString & category, const TQString & filename)
+Memofile * Memofiles::tqfind (const TQString & category, const TQString & filename)
{
Memofile * memofile;
@@ -353,7 +353,7 @@ void Memofiles::deleteMemo(PilotMemo * memo)
if (! memo->isDeleted())
return;
- Memofile * memofile = find(memo->id());
+ Memofile * memofile = tqfind(memo->id());
if (memofile) {
memofile->deleteFile();
_memofiles.remove(memofile);
@@ -375,7 +375,7 @@ void Memofiles::addModifiedMemo (PilotMemo * memo)
+ TQString::number(memo->id()) + CSL1("], title: [")
+ memo->getTitle() + CSL1("]. ");
- Memofile * memofile = find(memo->id());
+ Memofile * memofile = tqfind(memo->id());
if (NULL == memofile) {
_cudCounter.created();
@@ -653,7 +653,7 @@ TQString Memofiles::filename(PilotMemo * memo)
if (filename.isEmpty()) {
TQString text = memo->text();
- int i = text.find(CSL1("\n"));
+ int i = text.tqfind(CSL1("\n"));
if (i > 1) {
filename = text.left(i);
}
@@ -666,7 +666,7 @@ TQString Memofiles::filename(PilotMemo * memo)
TQString category = _categories[memo->category()];
- Memofile * memofile = find(category, filename);
+ Memofile * memofile = tqfind(category, filename);
// if we couldn't find a memofile with this filename, or if the
// memofile that is found is the same as the memo that we're looking
@@ -683,7 +683,7 @@ TQString Memofiles::filename(PilotMemo * memo)
// for trouble.
while (NULL != memofile && uniq <=20) {
newfilename = TQString(filename + CSL1(".") + TQString::number(uniq++) );
- memofile = find(category, newfilename);
+ memofile = tqfind(category, newfilename);
}
return newfilename;
diff --git a/conduits/memofileconduit/memofiles.h b/conduits/memofileconduit/memofiles.h
index 72b6ed4..290cf3a 100644
--- a/conduits/memofileconduit/memofiles.h
+++ b/conduits/memofileconduit/memofiles.h
@@ -55,8 +55,8 @@ public:
TQPtrList getModified();
TQPtrList getAll() { return _memofiles; } ;
- Memofile * find (const TQString & category, const TQString & filename);
- Memofile * find (recordid_t id);
+ Memofile * tqfind (const TQString & category, const TQString & filename);
+ Memofile * tqfind (recordid_t id);
MemoCategoryMap readCategoryMetadata();
void setCategories(MemoCategoryMap map) { _categories = map; } ;
diff --git a/conduits/memofileconduit/setup_base.ui b/conduits/memofileconduit/setup_base.ui
index 5053469..606bf5e 100644
--- a/conduits/memofileconduit/setup_base.ui
+++ b/conduits/memofileconduit/setup_base.ui
@@ -3,7 +3,7 @@
A tabWidget for configuring
the Memofile-conduit settings.
Jason 'vanRijn' Kasper
-
+
Form1
@@ -46,7 +46,7 @@ the Memofile-conduit settings.
6
-
+
tabWidget
@@ -60,7 +60,7 @@ the Memofile-conduit settings.
-
+
Widget2
@@ -88,7 +88,7 @@ the Memofile-conduit settings.
-
+
textLabel2
@@ -96,7 +96,7 @@ the Memofile-conduit settings.
Sync private records:
-
+
textLabel1
@@ -115,7 +115,7 @@ the Memofile-conduit settings.
Select the directory you want to store your PDA's memos in
-
+
fSyncPrivate
diff --git a/conduits/notepadconduit/Makefile.am b/conduits/notepadconduit/Makefile.am
index 7a052da..ce08524 100644
--- a/conduits/notepadconduit/Makefile.am
+++ b/conduits/notepadconduit/Makefile.am
@@ -9,6 +9,6 @@ kde_module_LTLIBRARIES = conduit_notepad.la
conduit_notepad_la_SOURCES = notepadconduit.kcfgc notepad-setup.ui \
notepad-conduit.cc notepad-factory.cc
-conduit_notepad_la_LDFLAGS= -module $(KDE_PLUGIN) $(all_libraries)
+conduit_notepad_la_LDFLAGS= -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_notepad_la_LIBADD= ../../lib/libkpilot.la $(LIB_KDEUI) $(LIB_KIO)
diff --git a/conduits/notepadconduit/notepad-conduit.cc b/conduits/notepadconduit/notepad-conduit.cc
index 10d9bf7..c33bd41 100644
--- a/conduits/notepadconduit/notepad-conduit.cc
+++ b/conduits/notepadconduit/notepad-conduit.cc
@@ -76,7 +76,7 @@ NotepadConduit::~NotepadConduit()
TQDir dir(NotepadConduitSettings::outputDirectory());
if(!dir.exists() && !dir.mkdir(dir.path())) {
- emit logError(i18n("Unable to open %1").arg(dir.path()));
+ emit logError(i18n("Unable to open %1").tqarg(dir.path()));
delayDone();
return false;
}
@@ -115,8 +115,8 @@ bool NotepadConduit::event(TQEvent *e)
// NotepadActionThread
//-----------------------------------------------------------------------------
-NotepadActionThread::NotepadActionThread(TQObject *parent, KPilotLink *link) :
- fParent(parent), fLink(link), notSaved(0), saved(0)
+NotepadActionThread::NotepadActionThread(TQObject *tqparent, KPilotLink *link) :
+ fParent(tqparent), fLink(link), notSaved(0), saved(0)
{
FUNCTIONSETUP;
}
@@ -251,7 +251,7 @@ void NotepadActionThread::saveImage(struct NotePad *n)
n->changeDate.min,
n->changeDate.sec);
}
- TQString imgname = TQString("%1/%2.png").arg(NotepadConduitSettings::outputDirectory()).arg(filename);
+ TQString imgname = TQString("%1/%2.png").tqarg(NotepadConduitSettings::outputDirectory()).tqarg(filename);
#ifdef DEBUG
diff --git a/conduits/notepadconduit/notepad-conduit.h b/conduits/notepadconduit/notepad-conduit.h
index 907a306..6f76768 100644
--- a/conduits/notepadconduit/notepad-conduit.h
+++ b/conduits/notepadconduit/notepad-conduit.h
@@ -59,10 +59,10 @@ private:
/**
* This class saves the notepads to disk
*/
-class NotepadActionThread : public QThread
+class NotepadActionThread : public TQThread
{
public:
- NotepadActionThread(TQObject *parent, KPilotLink *link);
+ NotepadActionThread(TQObject *tqparent, KPilotLink *link);
virtual void run();
int getFailed() { return notSaved; }
diff --git a/conduits/notepadconduit/notepad-factory.cc b/conduits/notepadconduit/notepad-factory.cc
index 0e1094b..fdb0841 100644
--- a/conduits/notepadconduit/notepad-factory.cc
+++ b/conduits/notepadconduit/notepad-factory.cc
@@ -47,7 +47,7 @@
class NotepadConduitConfig : public ConduitConfigBase
{
public:
- NotepadConduitConfig(TQWidget *parent=0L, const char *n=0L);
+ NotepadConduitConfig(TQWidget *tqparent=0L, const char *n=0L);
virtual void commit();
virtual void load();
static ConduitConfigBase *create(TQWidget *p, const char *n)
diff --git a/conduits/notepadconduit/notepad-setup.ui b/conduits/notepadconduit/notepad-setup.ui
index c625d97..d7fd026 100644
--- a/conduits/notepadconduit/notepad-setup.ui
+++ b/conduits/notepadconduit/notepad-setup.ui
@@ -1,7 +1,7 @@
NotepadWidget
Jörn Ahrens
-
+
Form2
@@ -20,11 +20,11 @@
unnamed
-
+
tabWidget
-
+
tab
@@ -57,7 +57,7 @@
fOutputDirectory
-
+
textLabel1
diff --git a/conduits/null/Makefile.am b/conduits/null/Makefile.am
index 783e881..bdcc43f 100644
--- a/conduits/null/Makefile.am
+++ b/conduits/null/Makefile.am
@@ -9,7 +9,7 @@ kde_module_LTLIBRARIES = conduit_null.la
conduit_null_la_SOURCES = nullSettings.kcfgc setup_base.ui null-conduit.cc null-factory.cc
-conduit_null_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_null_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_null_la_LIBADD = ../../lib/libkpilot.la $(LIB_KDEUI)
kde_kcfg_DATA = nullconduit.kcfg
diff --git a/conduits/null/null-conduit.cc b/conduits/null/null-conduit.cc
index d0c07c5..29d2499 100644
--- a/conduits/null/null-conduit.cc
+++ b/conduits/null/null-conduit.cc
@@ -35,7 +35,7 @@
// Only include what we really need:
// First UNIX system stuff, then std C++,
-// then Qt, then KDE, then local includes.
+// then TQt, then KDE, then local includes.
//
//
#include
diff --git a/conduits/null/null-factory.cc b/conduits/null/null-factory.cc
index c2d381d..6b80615 100644
--- a/conduits/null/null-factory.cc
+++ b/conduits/null/null-factory.cc
@@ -47,7 +47,7 @@
class NullConduitConfig : public ConduitConfigBase
{
public:
- NullConduitConfig(TQWidget *parent=0L, const char *n=0L);
+ NullConduitConfig(TQWidget *tqparent=0L, const char *n=0L);
virtual void commit();
virtual void load();
protected:
diff --git a/conduits/null/setup_base.ui b/conduits/null/setup_base.ui
index 2bcb518..ed7d234 100644
--- a/conduits/null/setup_base.ui
+++ b/conduits/null/setup_base.ui
@@ -3,7 +3,7 @@
A tabWidget for configuring
the Null-conduit settings.
Adriaan de Groot
-
+
Form1
@@ -46,7 +46,7 @@ the Null-conduit settings.
6
-
+
tabWidget
@@ -60,7 +60,7 @@ the Null-conduit settings.
-
+
Widget2
@@ -77,7 +77,7 @@ the Null-conduit settings.
6
-
+
fLogMessage
@@ -88,7 +88,7 @@ the Null-conduit settings.
<qt>Enter the message to add to the Sync Log on your Pilot here.</qt>
-
+
TextLabel1_2
diff --git a/conduits/popmail/Makefile.am b/conduits/popmail/Makefile.am
index 5b6becd..365cd1b 100644
--- a/conduits/popmail/Makefile.am
+++ b/conduits/popmail/Makefile.am
@@ -16,7 +16,7 @@ kde_module_LTLIBRARIES = conduit_popmail.la
conduit_popmail_la_SOURCES = popmailSettings.kcfgc setup-dialog.ui \
popmail-factory.cc setupDialog.cc \
popmail-conduit.cc
-conduit_popmail_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_popmail_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui -lDCOP
conduit_popmail_la_LIBADD = ../../lib/libkpilot.la $(LIB_KIO)
# this option you can leave out. Just, if you use "make dist", you need it
diff --git a/conduits/popmail/setup-dialog.ui b/conduits/popmail/setup-dialog.ui
index d9cf74e..e82f4ad 100644
--- a/conduits/popmail/setup-dialog.ui
+++ b/conduits/popmail/setup-dialog.ui
@@ -1,6 +1,6 @@
PopMailWidget
-
+
PopMailWidget
@@ -22,11 +22,11 @@
6
-
+
fTabWidget
-
+
tab
@@ -54,7 +54,7 @@
-
+
textLabel1_2
@@ -65,7 +65,7 @@
<qt>Select the method KPilot will use to send the mail from your Handheld to the recipients here. Depending on the method you choose, the other fields in the dialog may be enabled or disabled. Currently, the only <i>working</i> method is through KMail.</qt>
-
+
textLabel1
@@ -87,7 +87,7 @@
<qt>Enter the email address you want to send messages as here.</qt>
-
+
textLabel2
@@ -95,7 +95,7 @@
Signature file:
- <qt>If you want to add a signature file, enter the location of your signature file (usually, <i>.signature</i>, located in your home folder) here, or select it clicking the file picker button. The signature file tqcontains the text that is added to the end of your outgoing mail messages.</qt>
+ <qt>If you want to add a signature file, enter the location of your signature file (usually, <i>.signature</i>, located in your home folder) here, or select it clicking the file picker button. The signature file contains the text that is added to the end of your outgoing mail messages.</qt>
@@ -103,10 +103,10 @@
fSignature
- <qt>If you want to add a signature file, enter the location of your signature file (usually, <i>.signature</i>, located in your home folder) here, or select it clicking the file picker button. The signature file tqcontains the text that is added to the end of your outgoing mail messages.</qt>
+ <qt>If you want to add a signature file, enter the location of your signature file (usually, <i>.signature</i>, located in your home folder) here, or select it clicking the file picker button. The signature file contains the text that is added to the end of your outgoing mail messages.</qt>
-
+
-
Do Not Send Mail
diff --git a/conduits/popmail/setupDialog.h b/conduits/popmail/setupDialog.h
index 76bf9af..cc9d831 100644
--- a/conduits/popmail/setupDialog.h
+++ b/conduits/popmail/setupDialog.h
@@ -40,6 +40,7 @@ class PopMailWidget; // From setup-dialog.ui
class PopMailWidgetConfig : public ConduitConfigBase
{
Q_OBJECT
+ TQ_OBJECT
public:
PopMailWidgetConfig(TQWidget *, const char *);
virtual void load();
diff --git a/conduits/recordconduit/Makefile.am b/conduits/recordconduit/Makefile.am
index 9fd691e..e00693a 100644
--- a/conduits/recordconduit/Makefile.am
+++ b/conduits/recordconduit/Makefile.am
@@ -9,7 +9,7 @@ kde_module_LTLIBRARIES = conduit_record.la
conduit_record_la_SOURCES = settings.kcfgc setup_base.ui factory.cc
-conduit_record_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_record_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_record_la_LIBADD = ../../lib/libkpilot.la $(LIB_KDEUI)
kde_kcfg_DATA = settings.kcfg
diff --git a/conduits/recordconduit/factory.cc b/conduits/recordconduit/factory.cc
index 8337733..76b790e 100644
--- a/conduits/recordconduit/factory.cc
+++ b/conduits/recordconduit/factory.cc
@@ -48,7 +48,7 @@
class ConduitConfig : public ConduitConfigBase
{
public:
- ConduitConfig(TQWidget *parent=0L, const char *n=0L);
+ ConduitConfig(TQWidget *tqparent=0L, const char *n=0L);
virtual void commit();
virtual void load();
protected:
diff --git a/conduits/recordconduit/setup_base.ui b/conduits/recordconduit/setup_base.ui
index 8bd9790..389219b 100644
--- a/conduits/recordconduit/setup_base.ui
+++ b/conduits/recordconduit/setup_base.ui
@@ -3,7 +3,7 @@
A tabWidget for configuring
the Record-conduit settings.
Adriaan de Groot
-
+
Form1
@@ -46,7 +46,7 @@ the Record-conduit settings.
6
-
+
tabWidget
@@ -60,7 +60,7 @@ the Record-conduit settings.
-
+
Widget2
@@ -77,7 +77,7 @@ the Record-conduit settings.
6
-
+
fLogMessage
@@ -88,7 +88,7 @@ the Record-conduit settings.
<qt>Enter the message to add to the Sync Log on your Pilot here.</qt>
-
+
TextLabel1_2
@@ -99,7 +99,7 @@ the Record-conduit settings.
fLogMessage
-
+
TextLabel2_2
@@ -110,7 +110,7 @@ the Record-conduit settings.
fDatabases
-
+
fDatabases
@@ -135,7 +135,7 @@ the Record-conduit settings.
-
+
fFailImmediately
diff --git a/conduits/sysinfoconduit/Makefile.am b/conduits/sysinfoconduit/Makefile.am
index b89b4df..3a5b59a 100644
--- a/conduits/sysinfoconduit/Makefile.am
+++ b/conduits/sysinfoconduit/Makefile.am
@@ -15,7 +15,7 @@ conduit_sysinfo_la_SOURCES = sysinfoSettings.kcfgc \
sysinfo-setup.cc \
sysinfo-conduit.cc \
sysinfo-setup_dialog.ui
-conduit_sysinfo_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
+conduit_sysinfo_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(PISOCK_LIB) $(LIB_QT) -lkdecore -lkio -lkdeui
conduit_sysinfo_la_LIBADD = ../../lib/libkpilot.la $(LIB_KDEUI) $(LIB_KIO)
kpilot_sysinfo_data_DATA = Template.html Template.txt
diff --git a/conduits/sysinfoconduit/Template.html b/conduits/sysinfoconduit/Template.html
index e5a33e0..56aa328 100644
--- a/conduits/sysinfoconduit/Template.html
+++ b/conduits/sysinfoconduit/Template.html
@@ -147,7 +147,7 @@
|
diff --git a/conduits/abbrowserconduit/resolutionDialog.cc b/conduits/abbrowserconduit/resolutionDialog.cc
index d9b7089..0064a68 100644
--- a/conduits/abbrowserconduit/resolutionDialog.cc
+++ b/conduits/abbrowserconduit/resolutionDialog.cc
@@ -43,15 +43,15 @@
* as well as its child radio buttons. There are two different constructors
* for them.
* Each controller has three child radio buttons, and if any of them is
* activated (stateChange), it sets the text of its parent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/
class ResolutionCheckListItem : TQCheckListItem {
public:
ResolutionCheckListItem(ResolutionItem*it, ResolutionTable*tb,
- TQListView*parent);
+ TQListView*tqparent);
ResolutionCheckListItem(TQString header, TQString text,
- ResolutionCheckListItem*parent);
+ ResolutionCheckListItem*tqparent);
~ResolutionCheckListItem() {};
virtual void stateChange(bool newstate);
virtual void setValue(TQString text);
@@ -73,12 +73,12 @@ protected:
ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
- ResolutionTable*tb, TQListView*parent) :
- TQCheckListItem(parent, TQString::null, TQCheckListItem::Controller),
+ ResolutionTable*tb, TQListView*tqparent) :
+ TQCheckListItem(tqparent, TQString(), TQCheckListItem::Controller),
fResItem(it),
isController(true),
- fCaption(it?(it->fName):(TQString::null)),
- fText(it?(it->fResolved):(TQString::null))
+ fCaption(it?(it->fName):(TQString())),
+ fText(it?(it->fResolved):(TQString()))
{
FUNCTIONSETUP;
if (it && tb)
@@ -119,8 +119,8 @@ ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
}
ResolutionCheckListItem::ResolutionCheckListItem(TQString text, TQString header,
- ResolutionCheckListItem*parent) :
- TQCheckListItem(parent, TQString(), TQCheckListItem::RadioButton),
+ ResolutionCheckListItem*tqparent) :
+ TQCheckListItem(tqparent, TQString(), TQCheckListItem::RadioButton),
fResItem(0L),
isController(false),
fCaption(header),
@@ -133,7 +133,7 @@ void ResolutionCheckListItem::stateChange(bool newstate)
{
if (newstate && !isController)
{
- ResolutionCheckListItem*par=static_cast(parent());
+ ResolutionCheckListItem*par=static_cast(tqparent());
{
par->setValue(fText);
}
@@ -159,7 +159,7 @@ void ResolutionCheckListItem::setCaption(TQString caption)
void ResolutionCheckListItem::updateText()
{
- TQString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").arg(fCaption).arg(fText));
+ TQString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").tqarg(fCaption).tqarg(fText));
newText.tqreplace(TQRegExp(CSL1("\n")),
i18n("Denoting newlines in Address entries. No need to translate", " | "));
setText(0, newText);
@@ -171,9 +171,9 @@ void ResolutionCheckListItem::updateText()
*
*****************************************************************/
-ResolutionDlg::ResolutionDlg( TQWidget* parent, KPilotLink*fH,
+ResolutionDlg::ResolutionDlg( TQWidget* tqparent, KPilotLink*fH,
const TQString &caption, const TQString &helpText, ResolutionTable*tab) :
- KDialogBase( parent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
+ KDialogBase( tqparent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
tickleTimer(0L),
fHandle(fH),
fTable(tab)
@@ -319,5 +319,5 @@ void ResolutionDlg::_tickle()
*/
ResolutionDlg::~ResolutionDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
@@ -43,15 +43,15 @@
* for them.
* Each controller has three child radio buttons, and if any of them is
- * activated (stateChange), it sets the text of its parent (which is the
+ * activated (stateChange), it sets the text of its tqparent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/
diff --git a/conduits/docconduit/doc-conduit.cc b/conduits/docconduit/doc-conduit.cc
index 54f1ab4..0bce0fe 100644
--- a/conduits/docconduit/doc-conduit.cc
+++ b/conduits/docconduit/doc-conduit.cc
@@ -163,7 +163,7 @@ bool DOCConduit::pcTextChanged(TQString txtfn)
KMD5 docmd5;
TQFile txtfile(txtfn);
if (txtfile.open(IO_ReadOnly)){
- docmd5.update(txtfile);
+ docmd5.update(*TQT_TQIODEVICE(&txtfile));
TQString thisDigest(docmd5.hexDigest() /* .data() */);
#ifdef DEBUG
DEBUGKPILOT<<"New digest is "<config()->writeEntry(docconverter.txtFilename(), thisDigest);
DOCConduitSettings::self()->config()->sync();
@@ -378,10 +378,10 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
if (!postSyncAction(database, sinfo, res))
emit logError(i18n("Unable to install the locally created PalmDOC %1 to the handheld.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
if (!res)
emit logError(i18n("Conversion of PalmDOC \"%1\" failed.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
// disconnect(&docconverter, TQT_SIGNAL(logError(const TQString &)), TQT_SIGNAL(logError(const TQString &)));
// disconnect(&docconverter, TQT_SIGNAL(logMessage(const TQString &)), TQT_SIGNAL(logMessage(const TQString &)));
// KPILOT_DELETE(database);
@@ -389,7 +389,7 @@ bool DOCConduit::doSync(docSyncInfo &sinfo)
else
{
emit logError(i18n("Unable to open or create the database %1.")
- .arg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
+ .tqarg(TQString::tqfromLatin1(sinfo.dbinfo.name)));
}
return res;
}
@@ -665,7 +665,7 @@ void DOCConduit::syncDatabases() {
case eSyncDelete:
case eSyncPDAToPC:
case eSyncPCToPDA:
- emit logMessage(i18n("Synchronizing text \"%1\"").arg(sinfo.handheldDB));
+ emit logMessage(i18n("Synchronizing text \"%1\"").tqarg(sinfo.handheldDB));
if (!doSync(sinfo)) {
// The sync could not be done, so inform the user (the error message should probably issued inside doSync)
#ifdef DEBUG
@@ -716,29 +716,29 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
N N | C P H
*/
- if (TQFile::exists(sinfo.txtfilename)) sinfo.fPCStatus=eStatNew;
- else sinfo.fPCStatus=eStatDoesntExist;
- if (docdb && docdb->isOpen()) sinfo.fPalmStatus=eStatNew;
- else sinfo.fPalmStatus=eStatDoesntExist;
+ if (TQFile::exists(sinfo.txtfilename)) sinfo.fPCtqStatus=eStatNew;
+ else sinfo.fPCtqStatus=eStatDoesntExist;
+ if (docdb && docdb->isOpen()) sinfo.fPalmtqStatus=eStatNew;
+ else sinfo.fPalmtqStatus=eStatDoesntExist;
KPILOT_DELETE(docdb);
switch (eSyncDirection) {
case eSyncPDAToPC:
- if (sinfo.fPalmStatus==eStatDoesntExist)
+ if (sinfo.fPalmtqStatus==eStatDoesntExist)
sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPDAToPC;
break;
case eSyncPCToPDA:
- if (sinfo.fPCStatus==eStatDoesntExist)
+ if (sinfo.fPCtqStatus==eStatDoesntExist)
sinfo.direction=eSyncDelete;
else sinfo.direction=eSyncPCToPDA;
break;
case eSyncNone: // means actually both directions!
- if (sinfo.fPCStatus==eStatNew) {
- if (sinfo.fPalmStatus==eStatNew) sinfo.direction=eSyncConflict;
+ if (sinfo.fPCtqStatus==eStatNew) {
+ if (sinfo.fPalmtqStatus==eStatNew) sinfo.direction=eSyncConflict;
else sinfo.direction=eSyncPCToPDA;
} else {
- if (sinfo.fPalmStatus==eStatNew) sinfo.direction=eSyncPDAToPC;
+ if (sinfo.fPalmtqStatus==eStatNew) sinfo.direction=eSyncPDAToPC;
else {
sinfo.direction=eSyncNone;
#ifdef DEBUG
@@ -756,9 +756,9 @@ bool DOCConduit::needsSync(docSyncInfo &sinfo)
}
// Text was included in the last sync
- if (!TQFile::exists(sinfo.txtfilename)) sinfo.fPCStatus=eStatDeleted;
+ if (!TQFile::exists(sinfo.txtfilename)) sinfo.fPCtqStatus=eStatDeleted;
else if(pcTextChanged(sinfo.txtfilename)) {
- sinfo.fPCStatus=eStatChanged;
+ sinfo.fPCtqStatus=eStatChanged;
#ifdef DEBUG
DEBUGKPILOT<<"PC side has changed!"<isOpen()) sinfo.fPalmStatus=eStatDeleted;
+ if (!docdb || !docdb->isOpen()) sinfo.fPalmtqStatus=eStatDeleted;
else if (hhTextChanged(docdb)) {
#ifdef DEBUG
DEBUGKPILOT<<"Handheld side has changed!"<
-ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, syncInfoList*sinfo, KPilotLink*lnk )
- : KDialogBase( parent, "resolutionDialog", true, caption, KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true), tickleTimer(0L), fHandle(lnk) {
+ResolutionDialog::ResolutionDialog( TQWidget* tqparent, const TQString& caption, syncInfoList*sinfo, KPilotLink*lnk )
+ : KDialogBase( tqparent, "resolutionDialog", true, caption, KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true), tickleTimer(0L), fHandle(lnk) {
FUNCTIONSETUP;
syncInfo=sinfo;
hasConflicts=false;
@@ -70,7 +70,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
resolutionGroupBoxLayout = new TQGridLayout( big_box, syncInfo->size(), 3 );
- resolutionGroupBoxLayout->tqsetAlignment( Qt::AlignTop );
+ resolutionGroupBoxLayout->tqsetAlignment( TQt::AlignTop );
// Invisible button group for the information buttons to use the same slot for all of them (see Dallheimer's book, page 309f)
TQButtonGroup *bgroup = new TQButtonGroup( this );
@@ -138,7 +138,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
*/
ResolutionDialog::~ResolutionDialog()
{
// no need to delete child widgets, Qt does it all for us
}
/* virtual slot */ void ResolutionDialog::slotOk() {
@@ -150,7 +150,7 @@ ResolutionDialog::~ResolutionDialog()
KDialogBase::slotOk();
}
-TQString eTexStatusToString(eTexStatus stat) {
+TQString eTexStatusToString(eTextqStatus stat) {
switch(stat) {
case eStatNone: return i18n("unchanged");
case eStatNew: return i18n("new");
@@ -168,9 +168,9 @@ void ResolutionDialog::slotInfo(int index) {
int ix=cE.index;
if (!syncInfo) return;
docSyncInfo si=(*syncInfo)[ix];
- TQString text=i18n("Status of the database %1:\n\n").arg(si.handheldDB);
- text+=i18n("Handheld: %1\n").arg(eTexStatusToString(si.fPalmStatus));
- text+=i18n("Desktop: %1\n").arg(eTexStatusToString(si.fPCStatus));
+ TQString text=i18n("tqStatus of the database %1:\n\n").tqarg(si.handheldDB);
+ text+=i18n("Handheld: %1\n").tqarg(eTexStatusToString(si.fPalmtqStatus));
+ text+=i18n("Desktop: %1\n").tqarg(eTexStatusToString(si.fPCtqStatus));
KMessageBox::information(this, text, i18n("Database information"));
}
@@ -138,7 +138,7 @@ ResolutionDialog::ResolutionDialog( TQWidget* parent, const TQString& caption, s
ResolutionDialog::~ResolutionDialog()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/* virtual slot */ void ResolutionDialog::slotOk() {